==> nextcloud-23.0.7.tgz: nextcloud/apps/files/l10n/ia.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Immagazinage es provisorimente non disponibile",
    "Storage invalid" : "Immagazinage non valide",
    "Unknown error" : "Error incognite",
    "File could not be found" : "Impossibile trovar le file",
    "Download" : "Discargar",
    "Delete" : "Deler",
    "Home" : "Initio",
    "Close" : "Clauder",
    "Favorites" : "Favoritos",
    "Could not create folder \"{dir}\"" : "Impossibile crear dossier \"{dir}\"",
    "Upload cancelled." : "Incarga cancellate.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile incargar {filename} proque illo es un directorio o ha 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Il non ha satis de spatio libere, tu incarga {size1} ma il resta a pena {size2} in total",
    "Target folder \"{dir}\" does not exist any more" : "Le dossier de destination \"{dir}\" non existe plus",
    "Not enough free space" : "Il non ha satis de spatio libere",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Actions" : "Actiones",
    "Rename" : "Renominar",
    "Copy" : "Copiar",
    "Delete folder" : "Deler dossier",
    "Disconnect storage" : "Immagazinage disconnectite ",
    "Could not load info for file \"{file}\"" : "Impossibile cargar informationes pro file \"{file}\"",
    "Files" : "Files",
    "Details" : "Detalios",
    "Pending" : "Pendente",
    "Unable to determine date" : "Impossibile determinar data",
    "This operation is forbidden" : "Iste operation es prohibite",
    "This directory is unavailable, please check the logs or contact the administrator" : "Iste directorio non es disponibile, per favor verifica le registros o contacta le administrator",
    "Could not move \"{file}\", target exists" : "Impossibile displaciar \"{file}\": le destination ja existe",
    "Could not move \"{file}\"" : "Impossibile displaciar \"{file}\"",
    "{newName} already exists" : "{newName} ja existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossibile renominar \"{fileName}\": illo non existe plus",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nomine \"{targetName}\" es ja usate in le dossier \"{dir}\". Per favor, selectiona un nomine differente.",
    "Could not rename \"{fileName}\"" : "Impossibile renominar \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossibile crear file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossibile crear file \"{file}\" proque illo ja existe",
    "Could not create folder \"{dir}\" because it already exists" : "Impossibile crear dossier \"{dir}\" proque illo ja existe",
    "Error deleting file \"{fileName}\"." : "Error durante deletion del file \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nulle resultatos in altere dossiers pro le cerca {tag}{filter}{endtag}",
    "Name" : "Nomine",
    "Size" : "Dimension",
    "Modified" : "Modificate",
    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers"],
    "_%n file_::_%n files_" : ["%n file","%n files"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["includente %n occultate","includente %n occultates"],
    "_Uploading %n file_::_Uploading %n files_" : ["Incargante %n file","Incargante %n files"],
    "New" : "Nove",
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nomine de file non valide.",
    "File name cannot be empty." : "Le nomine de file non pote esser vacue.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" non es un typo de file valide ",
    "View in folder" : "Vider in dossier",
    "Copied!" : "Copiate!",
    "Path" : "Sentiero",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favorite",
    "Favorite" : "Favorite",
    "New folder" : "Nove dossier",
    "Upload file" : "Upload file",
    "Recent" : "Recente",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "An error occurred while trying to update the tags" : "Un error occurreva durante le actualisation del etiquettas",
    "Added to favorites" : "Addite al favoritos",
    "Removed from favorites" : "Removite del favoritos",
    "You added {file} to your favorites" : "Tu addeva {file} a tu favoritos",
    "You removed {file} from your favorites" : "Tu removeva {file} de tu favortos",
    "File changes" : "Modificationes del file",
    "Created by {user}" : "Create per {user}",
    "Changed by {user}" : "Modificate per {user}",
    "Deleted by {user}" : "Delite per {user}",
    "Restored by {user}" : "Restaurate per {user}",
    "Renamed by {user}" : "Renominate per {user}",
    "Moved by {user}" : "Displaciate per {user}",
    "\"remote user\"" : "\"usator remote\"",
    "You created {file}" : "Tu creava {file}",
    "{user} created {file}" : "{user} creava {file}",
    "{file} was created in a public folder" : "{file} esseva create in un dossier public",
    "You changed {file}" : "Tu modificava {file}",
    "{user} changed {file}" : "{user} modificava {file}",
    "You deleted {file}" : "Tu deleva {file}",
    "{user} deleted {file}" : "{user} deleva {file}",
    "You restored {file}" : "Tu restaurava {file}",
    "{user} restored {file}" : "{user} restaurava {file}",
    "You renamed {oldfile} to {newfile}" : "Tu renominava {oldfile} a {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renominava {oldfile} a {newfile}",
    "You moved {oldfile} to {newfile}" : "Tu displaciava {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} displaciava {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un file esseva addite a o removite de tu <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un file o dossier ha essite <strong>modificate</strong>",
    "All files" : "Tote files",
    "Unlimited" : "Ilimitate",
    "Upload (max. %s)" : "Incarga (maxime %s)",
    "Accept" : "Acceptar",
    "in %s" : "in %s",
    "Tags" : "Etiquettas",
    "Cancel" : "Cancellar",
    "Create" : "Crear",
    "%1$s of %2$s used" : "%1$s de %2$s usate",
    "Settings" : "Configurationes",
    "Show hidden files" : "Monstrar files occultate",
    "WebDAV" : "WebDAV",
    "No files in here" : "Nulle files ci",
    "Upload some content or sync with your devices!" : "Incarga alcun contento o synchronisa con tu apparatos!",
    "No entries found in this folder" : "Nulle entratas trovate in iste dossier",
    "Select all" : "Selectionar toto",
    "Upload too large" : "Incarga troppo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Le files que tu tenta incargar excede le dimension maxime pro incarga de files in iste servitor.",
    "Files and folders you mark as favorite will show up here" : "Files e dossiers que tu marca como favorito essera monstrate ci",
    "Deleted files" : "Files delite",
    "Shares" : "Compartimentos",
    "Shared with others" : "Compartite con alteres",
    "Shared with you" : "Compartite con te",
    "Shared by link" : "Compartite per ligamine",
    "Text file" : "File de texto",
    "New text file.txt" : "Nove texto file.txt",
    "Select" : "Selectionar",
    "You don’t have permission to upload or create files here" : "Tu non ha permission pro incargar o crear files ci."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.8.tgz: nextcloud/apps/files/l10n/ia.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Immagazinage es provisorimente non disponibile",
    "Storage invalid" : "Immagazinage non valide",
    "Unknown error" : "Error incognite",
    "File could not be found" : "Impossibile trovar le file",
    "Download" : "Discargar",
    "Delete" : "Deler",
    "Home" : "Initio",
    "Close" : "Clauder",
    "Favorites" : "Favoritos",
    "Could not create folder \"{dir}\"" : "Impossibile crear dossier \"{dir}\"",
    "Upload cancelled." : "Incarga cancellate.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Impossibile incargar {filename} proque illo es un directorio o ha 0 bytes",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Il non ha satis de spatio libere, tu incarga {size1} ma il resta a pena {size2} in total",
    "Target folder \"{dir}\" does not exist any more" : "Le dossier de destination \"{dir}\" non existe plus",
    "Not enough free space" : "Il non ha satis de spatio libere",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} de {totalSize} ({bitrate})",
    "Actions" : "Actiones",
    "Rename" : "Renominar",
    "Copy" : "Copiar",
    "Delete folder" : "Deler dossier",
    "Disconnect storage" : "Immagazinage disconnectite ",
    "Could not load info for file \"{file}\"" : "Impossibile cargar informationes pro file \"{file}\"",
    "Files" : "Files",
    "Details" : "Detalios",
    "Pending" : "Pendente",
    "Unable to determine date" : "Impossibile determinar data",
    "This operation is forbidden" : "Iste operation es prohibite",
    "This directory is unavailable, please check the logs or contact the administrator" : "Iste directorio non es disponibile, per favor verifica le registros o contacta le administrator",
    "Could not move \"{file}\", target exists" : "Impossibile displaciar \"{file}\": le destination ja existe",
    "Could not move \"{file}\"" : "Impossibile displaciar \"{file}\"",
    "{newName} already exists" : "{newName} ja existe",
    "Could not rename \"{fileName}\", it does not exist any more" : "Impossibile renominar \"{fileName}\": illo non existe plus",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Le nomine \"{targetName}\" es ja usate in le dossier \"{dir}\". Per favor, selectiona un nomine differente.",
    "Could not rename \"{fileName}\"" : "Impossibile renominar \"{fileName}\"",
    "Could not create file \"{file}\"" : "Impossibile crear file \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Impossibile crear file \"{file}\" proque illo ja existe",
    "Could not create folder \"{dir}\" because it already exists" : "Impossibile crear dossier \"{dir}\" proque illo ja existe",
    "Error deleting file \"{fileName}\"." : "Error durante deletion del file \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nulle resultatos in altere dossiers pro le cerca {tag}{filter}{endtag}",
    "Name" : "Nomine",
    "Size" : "Dimension",
    "Modified" : "Modificate",
    "_%n folder_::_%n folders_" : ["%n dossier","%n dossiers"],
    "_%n file_::_%n files_" : ["%n file","%n files"],
    "{dirs} and {files}" : "{dirs} e {files}",
    "_including %n hidden_::_including %n hidden_" : ["includente %n occultate","includente %n occultates"],
    "_Uploading %n file_::_Uploading %n files_" : ["Incargante %n file","Incargante %n files"],
    "\"{name}\" is an invalid file name." : "\"{name}\" es un nomine de file non valide.",
    "File name cannot be empty." : "Le nomine de file non pote esser vacue.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" non es un typo de file valide ",
    "View in folder" : "Vider in dossier",
    "Copied!" : "Copiate!",
    "Path" : "Sentiero",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Favorite",
    "Favorite" : "Favorite",
    "New folder" : "Nove dossier",
    "Upload file" : "Upload file",
    "Recent" : "Recente",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "An error occurred while trying to update the tags" : "Un error occurreva durante le actualisation del etiquettas",
    "Added to favorites" : "Addite al favoritos",
    "Removed from favorites" : "Removite del favoritos",
    "You added {file} to your favorites" : "Tu addeva {file} a tu favoritos",
    "You removed {file} from your favorites" : "Tu removeva {file} de tu favortos",
    "File changes" : "Modificationes del file",
    "Created by {user}" : "Create per {user}",
    "Changed by {user}" : "Modificate per {user}",
    "Deleted by {user}" : "Delite per {user}",
    "Restored by {user}" : "Restaurate per {user}",
    "Renamed by {user}" : "Renominate per {user}",
    "Moved by {user}" : "Displaciate per {user}",
    "\"remote user\"" : "\"usator remote\"",
    "You created {file}" : "Tu creava {file}",
    "{user} created {file}" : "{user} creava {file}",
    "{file} was created in a public folder" : "{file} esseva create in un dossier public",
    "You changed {file}" : "Tu modificava {file}",
    "{user} changed {file}" : "{user} modificava {file}",
    "You deleted {file}" : "Tu deleva {file}",
    "{user} deleted {file}" : "{user} deleva {file}",
    "You restored {file}" : "Tu restaurava {file}",
    "{user} restored {file}" : "{user} restaurava {file}",
    "You renamed {oldfile} to {newfile}" : "Tu renominava {oldfile} a {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} renominava {oldfile} a {newfile}",
    "You moved {oldfile} to {newfile}" : "Tu displaciava {oldfile} a {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} displaciava {oldfile} a {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un file esseva addite a o removite de tu <strong>favoritos</strong>",
    "A file or folder has been <strong>changed</strong>" : "Un file o dossier ha essite <strong>modificate</strong>",
    "All files" : "Tote files",
    "Unlimited" : "Ilimitate",
    "Upload (max. %s)" : "Incarga (maxime %s)",
    "Accept" : "Acceptar",
    "in %s" : "in %s",
    "Tags" : "Etiquettas",
    "Cancel" : "Cancellar",
    "Create" : "Crear",
    "%1$s of %2$s used" : "%1$s de %2$s usate",
    "Show hidden files" : "Monstrar files occultate",
    "WebDAV" : "WebDAV",
    "No files in here" : "Nulle files ci",
    "Upload some content or sync with your devices!" : "Incarga alcun contento o synchronisa con tu apparatos!",
    "No entries found in this folder" : "Nulle entratas trovate in iste dossier",
    "Select all" : "Selectionar toto",
    "Upload too large" : "Incarga troppo grande",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Le files que tu tenta incargar excede le dimension maxime pro incarga de files in iste servitor.",
    "Files and folders you mark as favorite will show up here" : "Files e dossiers que tu marca como favorito essera monstrate ci",
    "Deleted files" : "Files delite",
    "Shares" : "Compartimentos",
    "Shared with others" : "Compartite con alteres",
    "Shared with you" : "Compartite con te",
    "Shared by link" : "Compartite per ligamine",
    "Text file" : "File de texto",
    "New text file.txt" : "Nove texto file.txt",
    "Select" : "Selectionar",
    "You don’t have permission to upload or create files here" : "Tu non ha permission pro incargar o crear files ci.",
    "New" : "Nove",
    "Settings" : "Configurationes"
},
"nplurals=2; plural=(n != 1);");
